@@ -5,8 +5,7 @@
 import argparse
 from queue import Queue
 
-from ohmqtt.client import Client
-from ohmqtt.packet import MQTTPublishPacket
+from ohmqtt import Client, MQTTPublishPacket, MQTTQoS
 
 
 def main(args: argparse.Namespace) -> None:
@@ -16,8 +15,8 @@ def main(args: argparse.Namespace) -> None:
         client.wait_for_connect(timeout=5.0)
         print("*** Connected to broker")
 
-        pub = client.publish("ohmqtt/examples/publish_retain", b"test_payload", qos=1, retain=True)
-        assert pub.wait_for_ack()
+        pub = client.publish("ohmqtt/examples/publish_retain", b"test_payload", qos=MQTTQoS.Q1, retain=True)
+        pub.wait_for_ack(timeout=5.0)
 
         q: Queue[MQTTPublishPacket] = Queue()
         def callback(_: Client, msg: MQTTPublishPacket) -> None:
