@@ -31,12 +31,15 @@ from ohmqtt.error import MQTTError
 from ohmqtt.mqtt_spec import MQTTReasonCode
 from ohmqtt.packet import (
     decode_packet,
+    MQTTPacket,
     MQTTConnectPacket,
     MQTTConnAckPacket,
     MQTTDisconnectPacket,
     MQTTPublishPacket,
     MQTTPingReqPacket,
     MQTTPingRespPacket,
+    MQTTSubscribePacket,
+    MQTTUnsubscribePacket,
     PING,
     PONG,
 )
@@ -836,6 +839,14 @@ def test_states_connected_read_packet(
     callbacks.assert_not_called()
     assert fsm.state is ClosingState
 
+    # Handle invalid packets.
+    for pt in (MQTTConnectPacket, MQTTSubscribePacket, MQTTUnsubscribePacket):
+        packet: MQTTPacket = pt()
+        decoder.decode.return_value = packet
+        with pytest.raises(MQTTError) as excinfo:
+            ConnectedState.read_packet(fsm, state_data, env, params)
+        assert excinfo.value.reason_code == MQTTReasonCode.ProtocolError
+
 
 @pytest.mark.parametrize("max_wait", [None, 0.0])
 def test_states_reconnect_wait_happy_path(
@@ -904,9 +915,11 @@ def test_states_reconnect_wait_race(
     callbacks.assert_not_called()
 
 
+@pytest.mark.parametrize("init_dc_rc", [MQTTReasonCode.UnspecifiedError, None])
 @pytest.mark.parametrize("address", ["mqtt://testhost", "mqtts://testhost"])
 @pytest.mark.parametrize("max_wait", [None, 0.0])
 def test_states_closing_happy_path(
+    init_dc_rc: MQTTReasonCode | None,
     address: str,
     max_wait: float | None,
     callbacks: EnvironmentCallbacks,
@@ -919,6 +932,7 @@ def test_states_closing_happy_path(
     params = ConnectParams(address=Address(address), connect_timeout=5)
     fsm = FSM(env=env, init_state=ClosingState, error_state=ShutdownState)
     mock_timeout.get_timeout.return_value = 1 if max_wait is None else max_wait
+    state_data.disconnect_rc = init_dc_rc
 
     # Start from ConnectedState to test transition through ClosingState to ClosedState.
     fsm.previous_state = ConnectedState
@@ -926,7 +940,7 @@ def test_states_closing_happy_path(
     assert mock_timeout.interval == params.connect_timeout
     mock_timeout.mark.assert_called_once()
     mock_timeout.reset_mock()
-    assert state_data.disconnect_rc == MQTTReasonCode.NormalDisconnection
+    assert state_data.disconnect_rc == MQTTReasonCode.NormalDisconnection if init_dc_rc is None else init_dc_rc
     if not params.address.use_tls:
         mock_socket.shutdown.assert_called_once_with(socket.SHUT_RD)
     else:
@@ -934,9 +948,20 @@ def test_states_closing_happy_path(
     mock_socket.reset_mock()
     assert fsm.state is ClosingState
 
-    # First handle, write all.
-    mock_select.select.return_value = (False, True)
     env.write_buffer.extend(b"test_data")
+
+    # First handle, write blocked.
+    mock_select.select.return_value = (False, False)
+    ret = ClosingState.handle(fsm, state_data, env, params, max_wait)
+    assert ret is False
+    mock_select.select.assert_called_once_with(write=True, timeout=1 if max_wait is None else max_wait)
+    mock_select.reset_mock()
+    mock_timeout.exceeded.assert_called_once()
+    mock_timeout.reset_mock()
+    assert fsm.state is ClosingState
+
+    # Second handle, write all.
+    mock_select.select.return_value = (False, True)
     mock_socket.send.return_value = len(env.write_buffer)
     ret = ClosingState.handle(fsm, state_data, env, params, max_wait)
     assert ret is False
@@ -948,7 +973,7 @@ def test_states_closing_happy_path(
     mock_timeout.reset_mock()
     assert fsm.state is ClosingState
 
-    # Second handle, done writing, transition to ClosedState.
+    # Third handle, done writing, transition to ClosedState.
     ret = ClosingState.handle(fsm, state_data, env, params, max_wait)
     assert ret is True
     mock_timeout.exceeded.assert_called_once()
